pub struct ModelResponseEventStream { /* private fields */ }Expand description
Receiver for incremental canonical model stream events.
Implementations
Sourceimpl ModelResponseEventStream
impl ModelResponseEventStream
Sourcepub fn new(
receiver: Receiver<Result<ModelResponseStreamEvent, ModelError>>,
) -> Self
pub fn new( receiver: Receiver<Result<ModelResponseStreamEvent, ModelError>>, ) -> Self
Build a stream from a channel receiver.
Sourcepub const fn new_with_cancellation(
receiver: Receiver<Result<ModelResponseStreamEvent, ModelError>>,
cancellation_token: CancellationToken,
) -> Self
pub const fn new_with_cancellation( receiver: Receiver<Result<ModelResponseStreamEvent, ModelError>>, cancellation_token: CancellationToken, ) -> Self
Build a stream from a channel receiver and cancellation token.
Sourcepub const fn new_with_cancellation_and_drop_abort(
receiver: Receiver<Result<ModelResponseStreamEvent, ModelError>>,
cancellation_token: CancellationToken,
drop_abort_token: Option<CancellationToken>,
) -> Self
pub const fn new_with_cancellation_and_drop_abort( receiver: Receiver<Result<ModelResponseStreamEvent, ModelError>>, cancellation_token: CancellationToken, drop_abort_token: Option<CancellationToken>, ) -> Self
Build a stream from a channel receiver, cancellation token, and drop-abort token.
Sourcepub fn drop_abort_token(&self) -> Option<CancellationToken>
pub fn drop_abort_token(&self) -> Option<CancellationToken>
Return the transport-local drop-abort token, when the stream owns one.
Sourcepub async fn recv(
&mut self,
) -> Option<Result<ModelResponseStreamEvent, ModelError>>
pub async fn recv( &mut self, ) -> Option<Result<ModelResponseStreamEvent, ModelError>>
Receive the next canonical model stream event.