pub enum CachePointTtl {
FiveMinutes,
OneHour,
}Expand description
Cache-point lifetime for providers with per-breakpoint TTL controls.
Variants
FiveMinutes
Keep the cache entry for at least five minutes.
OneHour
Keep the cache entry for at least one hour.
Implementations