TestModel

Struct TestModel 

pub struct TestModel { /* private fields */ }
Deterministic model that returns scripted responses.

Implementations

Source

impl TestModel

pub fn new() -> Self

Create a test model with a default text response.

pub fn with_responses(responses: Vec<ModelResponse>) -> Self

Create a test model with scripted responses in call order.

pub fn with_stream_events(events: Vec<Vec<ModelResponseStreamEvent>>) -> Self

Create a test model with scripted stream event batches in call order.

pub fn with_text(text: impl Into<String>) -> Self

Create a test model returning plain text.

pub fn with_json(value: &Value) -> Self

Create a test model returning JSON text.

pub fn with_model_name(self, model_name: impl Into<String>) -> Self

Set model name.

pub fn with_profile(self, profile: ModelProfile) -> Self

Set model profile.

pub fn with_default_settings(self, settings: ModelSettings) -> Self

Set model default settings.

pub fn captured_messages(&self) -> Vec<Vec<ModelMessage>>

Return captured request histories.

pub fn captured_params(&self) -> Vec<ModelRequestParameters>

Return captured request parameters.